@@ -3,13 +3,12 @@ package HTTP::Headers::Util;
 use strict;
 use vars qw($VERSION @ISA @EXPORT_OK);
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
 
 require Exporter;
 @ISA=qw(Exporter);
 
-@EXPORT_OK=qw(split_etag_list join_etag_list
-              split_header_words join_header_words);
+@EXPORT_OK=qw(split_header_words join_header_words);
 
 =head1 NAME
 
@@ -22,11 +21,11 @@ HTTP::Headers::Util - Header value parsing utility functions
 
 =head1 DESCRIPTION
 
-This module provide a few functions that helps parsing and
+This module provides a few functions that helps parsing and
 construction of valid HTTP header values.  None of the functions are
 exported by default.
 
-The following functions are provided:
+The following functions are available:
 
 =over 4
 
@@ -35,7 +34,7 @@ The following functions are provided:
 
 This function will parse the header values given as argument into a
 list of anonymous arrays containing key/value pairs.  The function
-know how to deal with ",", ";" and "=" as well as quoted values after
+knows how to deal with ",", ";" and "=" as well as quoted values after
 "=".  A list of space separated tokens are parsed as if they were
 separated by ";".
 
@@ -43,7 +42,7 @@ If the @header_values passed as argument contains multiple values,
 then they are treated as if they were a single value separated by
 comma ",".
 
-This means that this function is useful to parse header fields that
+This means that this function is useful for parsing header fields that
 follow this syntax (BNF as from the HTTP/1.1 specification, but we relax
 the requirement for tokens).
 
@@ -65,7 +64,7 @@ the requirement for tokens).
   value             = token | quoted-string
 
 Each I<header> is represented by an anonymous array of key/value
-pairs.  If a token is recognized then the value will be C<undef>.
+pairs.  The value for a simple token (not part of a parameter) is C<undef>.
 Syntactically incorrect headers will not necessary be parsed as you
 would want.
 
@@ -124,9 +123,9 @@ sub split_header_words
 
 =item join_header_words( @arrays )
 
-This will do the opposite convertion of what split_header_words()
-does.  It takes a list of anonymous arrays as argument (or a list of
-key/value pairs) and produce a single header value.  Attribute values
+This will do the opposite of the conversion done by split_header_words().
+It takes a list of anonymous arrays as arguments (or a list of
+key/value pairs) and produces a single header value.  Attribute values
 are quoted if needed.
 
 Example:
@@ -165,59 +164,6 @@ sub join_header_words
     join(", ", @res);
 }
 
-=item split_etag_list( @header_values )
-
-Split a list of entity tag values.  The return value is a list
-consisting of one element per entity tag.  Suitable for parsing
-headers like C<If-Match>, C<If-None-Match>.  You might even want to
-use it on C<ETag> and C<If-Range> entity tag values, because it will
-normalize them to the common form.
-
-  entity-tag	  = [ weak ] opaque-tag
-  weak		  = "W/"
-  opaque-tag	  = quoted-string
-
-
-=cut
-
-sub split_etag_list
-{
-    my(@val) = @_;
-    my @res;
-    for (@val) {
-        while (length) {
-            my $weak = "";
-	    $weak = "W/" if s,^\s*[wW]/,,;
-            my $etag = "";
-	    if (s/^\s*(\"[^\"\\]*(?:\\.[^\"\\]*)*\")//) {
-		push(@res, "$weak$1");
-            } elsif (s/^\s*,//) {
-                push(@res, qq(W/"")) if $weak;
-            } elsif (s/^\s*([^,\s]+)//) {
-                $etag = $1;
-		$etag =~ s/([\"\\])/\\$1/g;
-	        push(@res, qq($weak"$etag"));
-            } elsif (s/^\s+// || !length) {
-                push(@res, qq(W/"")) if $weak;
-            } else {
-	 	die "This should not happen: '$_'";
-            }
-        }
-   }
-   @res;
-}
-
-=item join_etag_list(@list)
-
-Reverses the operation by split_etag_list().
-
-=cut
-
-sub join_etag_list
-{
-   join(", ", @_);
-}
-
 1;
 
 __END__
