@@ -1,10 +1,24 @@
 #
-# $Id: https.pm,v 1.6 1998/01/20 14:23:28 aas Exp $
+# $Id: https.pm,v 1.8 1999/09/20 12:48:37 gisle Exp $
 
 use strict;
 
 package LWP::Protocol::https;
-require Net::SSL;  # from Crypt-SSLeay
+
+# Figure out which SSL implementation to use
+use vars qw($SSL_CLASS);
+if ($IO::Socket::SSL::VERSION) {
+    $SSL_CLASS = "IO::Socket::SSL"; # it was already loaded
+} else {
+    eval { require Net::SSL; };     # from Crypt-SSLeay
+    if ($@) {
+	require IO::Socket::SSL;
+	$SSL_CLASS = "IO::Socket::SSL";
+    } else {
+	$SSL_CLASS = "Net::SSL";
+    }
+}
+
 
 use vars qw(@ISA);
 
@@ -14,12 +28,17 @@ require LWP::Protocol::http;
 sub _new_socket
 {
     my($self, $host, $port, $timeout) = @_;
-    my $sock = Net::SSL->new(PeerAddr => $host,
-			     PeerPort => $port,
-			     Proto    => 'tcp',
-			     Timeout  => $timeout,
-			    );
-    die "Can't connect to $host:$port" unless $sock;
+    local($^W) = 0;  # IO::Socket::INET can be noisy
+    my $sock = $SSL_CLASS->new(PeerAddr => $host,
+			       PeerPort => $port,
+			       Proto    => 'tcp',
+			       Timeout  => $timeout,
+			      );
+    unless ($sock) {
+	# IO::Socket::INET leaves additional error messages in $@
+	$@ =~ s/^.*?: //;
+	die "Can't connect to $host:$port ($@)";
+    }
     $sock;
 }
 
