@@ -1,4 +1,4 @@
-# $Id: RobotRules.pm,v 1.11 1996/09/30 11:45:10 aas Exp $
+# $Id: RobotRules.pm,v 1.18 1999/03/20 07:37:36 gisle Exp $
 
 package WWW::RobotRules;
 
@@ -30,29 +30,30 @@ WWW::RobotsRules - Parse robots.txt files
 
 =head1 DESCRIPTION
 
-This module parses a F<robots.txt> file as specified in
+This module parses a F</robots.txt> file as specified in
 "A Standard for Robot Exclusion", described in
-<URL:http://info.webcrawler.com/mak/projects/robots/norobots.html>
-Webmasters can use the F<robots.txt> file to disallow conforming
-robots access to parts of their WWW server.
+<http://info.webcrawler.com/mak/projects/robots/norobots.html>
+Webmasters can use the F</robots.txt> file to disallow conforming
+robots access to parts of their web site.
 
 The parsed file is kept in the WWW::RobotRules object, and this object
-provide methods to check if access to a given URL is prohibited.  The
-same WWW::RobotRules object can parse multiple F<robots.txt> files.
+provides methods to check if access to a given URL is prohibited.  The
+same WWW::RobotRules object can parse multiple F</robots.txt> files.
 
-=head1 METHODS
+The following methods are provided:
+
+=over 4
 
 =cut
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.18 $ =~ /(\d+)\.(\d+)/);
 sub Version { $VERSION; }
 
-
-use URI::URL ();
 use strict;
+use URI ();
 
 
-=head2 $rules = new WWW::RobotRules 'MOMspider/1.0'
+=item $rules = WWW::RobotRules->new($robot_name)
 
 This is the constructor for WWW::RobotRules objects.  The first 
 argument given to new() is the name of the robot. 
@@ -72,7 +73,7 @@ sub new {
 }
 
 
-=head2 $rules->parse($url, $content, $fresh_until)
+=item $rules->parse($url, $content, $fresh_until)
 
 The parse() method takes as arguments the URL that was used to
 retrieve the F</robots.txt> file, and the contents of the file.
@@ -81,9 +82,8 @@ retrieve the F</robots.txt> file, and the contents of the file.
 
 sub parse {
     my($self, $url, $txt, $fresh_until) = @_;
-
-    $url = new URI::URL $url unless ref($url);	# make it URL
-    my $netloc = $url->netloc;
+    $url = URI->new("$url");
+    my $netloc = $url->authority;
 
     $self->clear_rules($netloc);
     $self->fresh_until($netloc, $fresh_until || (time + 365*24*3600));
@@ -94,11 +94,20 @@ sub parse {
     my @me_disallowed = ();	# rules disallowed for me
     my @anon_disallowed = ();	# rules disallowed for *
 
-    for(split(/\n/, $txt)) {
-	s/\015$//g;
-	s/\s*\#.*//;
+    # blank lines are significant, so turn CRLF into LF to avoid generating
+    # false ones
+    $txt =~ s/\015\012/\012/g;
 
-	if (/^\s*$/) {		# blank line
+    # split at \012 (LF) or \015 (CR) (Mac text files have just CR for EOL)
+    for(split(/[\012\015]/, $txt)) {
+
+	# Lines containing only a comment are discarded completely, and
+        # therefore do not indicate a record boundary.
+	next if /^\s*\#/;
+
+	s/\s*\#.*//;        # remove comments at end-of-line
+
+	if (/^\s*$/) {	    # blank line
 	    last if $is_me; # That was our record. No need to read the rest.
 	    $is_anon = 0;
 	}
@@ -124,7 +133,7 @@ sub parse {
 	    my $disallow = $1;
 	    $disallow =~ s/\s+$//;
 	    if (length $disallow) {
-		$disallow = URI::URL->new($disallow, $url)->full_path;
+		$disallow = URI->new($disallow, $url)->path_query;
 	    }
 
 	    if ($is_me) {
@@ -153,11 +162,11 @@ sub parse {
 #
 sub is_me {
     my($self, $ua) = @_;
-    my $me = $self->{'ua'};
+    my $me = $self->agent;
     return index(lc($ua), lc($me)) >= 0;
 }
 
-=head2 $rules->allowed($url)
+=item $rules->allowed($url)
 
 Returns TRUE if this robot is allowed to retrieve this URL.
 
@@ -165,14 +174,13 @@ Returns TRUE if this robot is allowed to retrieve this URL.
 
 sub allowed {
     my($self, $url) = @_;
-    $url = URI::URL->new($url) unless ref $url;	# make it URL
-
-    my $netloc = $url->netloc;
+    $url = URI->new("$url");
+    my $netloc = $url->authority;
 
     my $fresh_until = $self->fresh_until($netloc);
     return -1 if !defined($fresh_until) || $fresh_until < time;
 
-    my $str = $url->full_path;
+    my $str = $url->path_query;
     my $rule;
     for $rule ($self->rules($netloc)) {
 	return 1 unless length $rule;
@@ -197,7 +205,7 @@ package WWW::RobotRules::InCore;
 use vars qw(@ISA);
 @ISA = qw(WWW::RobotRules);
 
-=head2 $rules->agent([$name])
+=item $rules->agent([$name])
 
 Get/set the agent name. NOTE: Changing the agent name will clear the robots.txt
 rules and expire times out of the cache.
@@ -221,7 +229,7 @@ sub visit {
     $self->{'loc'}{$netloc}{'last'} = $time;
     
     my $count = \$self->{'loc'}{$netloc}{'count'};
-    if (defined $$count) {
+    if (!defined $$count) {
 	$$count = 1;
     } else {
 	$$count++;
@@ -284,11 +292,13 @@ sub dump
 
 __END__
 
+=back
+
 =head1 ROBOTS.TXT
 
 The format and semantics of the "/robots.txt" file are as follows
 (this is an edited abstract of
-<URL:http://info.webcrawler.com/mak/projects/robots/norobots.html>):
+<http://info.webcrawler.com/mak/projects/robots/norobots.html>):
 
 The file consists of one or more records separated by one or more
 blank lines. Each record contains lines of the form
@@ -318,13 +328,11 @@ starts with this value will not be retrieved
 
 =back
 
-=head2 Examples
+=head1 ROBOTS.TXT EXAMPLES
 
 The following example "/robots.txt" file specifies that no robots
 should visit any URL starting with "/cyberworld/map/" or "/tmp/":
 
-  # robots.txt for http://www.site.com/
-
   User-agent: *
   Disallow: /cyberworld/map/ # This is an infinite virtual URL space
   Disallow: /tmp/ # these will soon disappear
@@ -333,8 +341,6 @@ This example "/robots.txt" file specifies that no robots should visit
 any URL starting with "/cyberworld/map/", except the robot called
 "cybermapper":
 
-  # robots.txt for http://www.site.com/
-
   User-agent: *
   Disallow: /cyberworld/map/ # This is an infinite virtual URL space
 
